The Best Shopping in Marrakech - Condé Nast Traveler
Author: Hanya Yanagihara
Description: Souks aren't the only shopping spots to visit in Marrakech, Morocco; these stores throughout the city are also worth a visit.
Date: 2014-12-08T18:26:46.427Z

### Sign Up for Free Traveler Newsletters

Enter your email address

Please enter a valid email.

We encountered a server error. Please try again later.

Please select a newsletter

Will be used in accordance with our Privacy Policy

The Daily TravelerDaily inspiration Travel IntelWeekly news and advice

### Thank you!

We've sent you an email to confirm your subscription.

×
Conde Nast Traveler

##### At Home in the World

###

- Share on Facebook.
- Tweet it!
- Pin It!
- Share on Google Plus.
- Share on LinkedIn.
- Print this Page
- Email to a Friend

Subscribe

Subscribe Now

### Share this Slideshow

- Share on Facebook.
- Tweet it!
- Pin It!
- Share on Google Plus.
- Share on LinkedIn.
- Print this Page
- Email to a Friend

## Around The Web

Powered by ZergNet

# The Best Shopping in Marrakech

In a way, no one actually needs a shopping guide to Marrakech: The city is so full of irresistible wonders (the souks alone could keep you busy for days) and terrific bargains that you almost can’t go wrong. Still, if you have limited time, these are the places to go.

## M’H

Belgian designer Martine Hillen’s gorgeous, lightweight, made-in-Morocco bags are cut into slouchy trapezoids or trimmed with long, luxurious leather shags. Most of them retail in the $250 range, far less then comparable bags in the States. She also stocks the full range of M’Tita Bamako’s recycled-plastic beach totes, embroidered pouches, and cotton bags printed with African leaders’ and politicians’ faces. (369 Q Sidi Ghanem; 212-667-350123)

## Topolina

Imagine if Auntie Mame moved to Marrakech and started designing clothes—that's the vibe at the Topolina showroom, where the walls are an aggressive hot pink, and the floors a jigsaw of mismatched carpets and rugs laid end to end. There are terrific discoveries here, but the real gems are Topolina’s own swingy, Mod-y separates and coats, including a charcoal-gray wool topper lined with black-and-white striped silk and cinched with a matching bel. (436 Zone Industrielle Sidi Ghanem; 212-651-3457-95)

## Magasin General

A Belgian couple with a background in interior design runs this large, airy store, where you can find pieces of vintage French china, throw pillows silkscreened with the faces of Mughal emperors, rose-scented candles, decoupaged plates, and antique leather saddlebags to fill your Provencal-by-way-of-Moroccan house. (369 Zone Industrielle Sidi Ghanem; 212-524-3366-73)

## Scenes de Lin

This elegant, polished interior design store interprets Marrakech through a Parisian lens. The best bets here are the bed linens, embroidered in crisp geometric shapes, and the heavy cotton blankets, which have the texture of silk, the heft of velvet, and are edged with elaborate stitching in contrasting colors. (70, rue El Houria; 212 24 43 61 08)

## Anitan

Rug shopping in the souk is invigorating…until it’s exhausting. You’ll pay higher prices at this smart, airy shop near the Jardin Majorelle, but the collection of Moroccan tribal and central Asian textiles is well-curated, easy to sort through, and, best of all, guaranteed to be of good quality (and they ship). Head upstairs for an excellent selection of well-made cotton towels and home accessories. (Rue Yves Saint Laurent Majorelle; 212 5243-32342)

## 33 Rue Majorelle

This sunlit, glass-walled store bills itself as Marrakech’s first concept shop. Inside, you’ll find an imaginative, colorful selection of clutches made from tribal rugs; lightweight cotton tunics; fabulous raffia brogues; wool baskets; and silver jewelry, most of it sourced from Morocco and northern Africa. Don’t leave without stopping by the adjoining café, Kaowa, for a smoothie—one combining cinnamon, dates, banana, and almond milk is particularly good. (33 Rue Yves Saint Laurent Majorelle; 212-5243-14195)

## Akbar

You’ll find unbelievably gorgeous beaded and embroidered caftans, tunics, toppers, and babouches (and clutches, bracelets, and shawls) at this jewel box of a shop in the medina. It’s not cheap, but it’ll provide inspiration for days. (Place Bab Fteuh; 212-6671-661307)

## Pop-up Shop

At this sliver of a shop, located above the pretty, jade green-tiled Le Jardin restaurant, you’ll find perfectly cut, floaty caftans, leather tassels to clip onto your handbags, and chic clutches and tote bags made from lizard, leather, and water snake. (32, Souk El Jeld Sidi Abdelaziz)

## Peacock Pavilions

Maryam Montague, the owner of this lovely, cheery boutique hotel works for a human rights NGO; runs her inn; writes and photographs; and sources rugs, textiles, accessories, and furniture from across Morocco, Central Asia, and Africa for a small clientele of high-profile fashion designers in New York and Europe. There’s a rotating selection of her finds available on her website, or you can stop by and see what she has in stock in person. (Kilometer 18, Route de Ouarzazate; 212-6644-14653; peacockpavilions.com)

1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
Where in the world are you thinking of?
Share This

- Share on Facebook.
- Tweet it!
- Pin It!
- Share on Google Plus.
- Share on LinkedIn.
- Print this Page
- Email to a Friend

×
An Error occurred while compiling your sass files. :(
Please find out what went wrong by consulting your friendly terminal.
We are sorry for any inconvenience this may have caused you.